/**
 * Copyright (C) 2011 Angelo Zerr <angelo.zerr@gmail.com> and Pascal Leclercq <pascal.leclercq@gmail.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package org.odftoolkit.odfdom.converter.internal.itext.stylable;

import java.awt.Color;

import org.odftoolkit.odfdom.converter.internal.itext.styles.Style;
import org.odftoolkit.odfdom.converter.internal.itext.styles.StyleParagraphProperties;
import org.odftoolkit.odfdom.converter.internal.itext.styles.StyleTextProperties;

import com.lowagie.text.Element;
import com.lowagie.text.Font;
import com.lowagie.text.Paragraph;

import fr.opensagres.xdocreport.itext.extension.ExtendedParagraph;

public class StylableParagraph extends ExtendedParagraph implements
		IStylableContainer {

	private static final long serialVersionUID = 664309269352903329L;

	private final StylableDocument ownerDocument;
	private IStylableContainer parent;
	private Style lastStyleApplied = null;

	public StylableParagraph(StylableDocument ownerDocument,
			IStylableContainer parent) {
		super();
		this.ownerDocument = ownerDocument;
		this.parent = parent;
	}

	public StylableParagraph(StylableDocument ownerDocument, Paragraph title,
			IStylableContainer parent) {
		super(title);
		this.ownerDocument = ownerDocument;
		this.parent = parent;
	}

	public void addElement(Element element) {
		super.add(element);
	}

	public void applyStyles(Style style) {
		this.lastStyleApplied = style;

		StyleTextProperties textProperties = style.getTextProperties();
		if (textProperties != null) {
			// Font
			Font font = textProperties.getFont();
			if (font != null) {
				super.setFont(font);
			}
		}

		StyleParagraphProperties paragraphProperties = style
				.getParagraphProperties();
		if (paragraphProperties != null) {

			boolean breakBeforePage = paragraphProperties.isBreakBeforePage();
			if (breakBeforePage) {
				ownerDocument.newPage();
			}
			
			// Alignment
			int alignment = paragraphProperties.getAlignment();
			if (alignment != Element.ALIGN_UNDEFINED) {
				super.setAlignment(alignment);
			}

			// Indentation
			Float indentation = paragraphProperties.getIndentation();
			if (indentation != null) {
				if (paragraphProperties.isAutoTextIndent()) {
					super.setIndentationLeft(indentation);
				} else {
					super.setFirstLineIndent(indentation);
				}
			}

			Float lineHeight = paragraphProperties.getLineHeight();
			if (lineHeight != null) {
				// super.getPdfPCell().setMinimumHeight(lineHeight);
				// FIXME : Is it correct???
				// super.setLeading(lineHeight * super.getTotalLeading());
			}

			Color backgroundColor = paragraphProperties.getBackgroundColor();
			if (backgroundColor != null) {
				super.getPdfPCell().setBackgroundColor(backgroundColor);
			}
		}

	}

	public Style getLastStyleApplied() {
		return lastStyleApplied;
	}

	public IStylableContainer getParent() {
		return parent;
	}

	public StylableDocument getOwnerDocument() {
		return ownerDocument;
	}

	public Element getElement() {
		return this;// super.getContainer();
	}
}
